@@ -1,3 +1,22 @@
+/* This file is part of Strigi Desktop Search
+ *
+ * Copyright (C) 2006 Ben van Klinken <bvklinken@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 #include "archiveenginehandler.h"
 #include "fsfileinputstream.h"
 #include "archivereader.h"
@@ -5,10 +24,9 @@
 #include <QtCore/QFSFileEngine>
 #include <QtCore/QDateTime>
 #include <QtCore/QDebug>
-using namespace jstreams;
 #include <iostream>
 using namespace std;
-#include <dirent.h>
+using namespace Strigi;
 
 class QFileStreamOpener : public StreamOpener {
 public:
@@ -18,8 +36,8 @@ public:
 };
 StreamBase<char>*
 QFileStreamOpener::openStream(const string& url) {
-    StreamBase<char>* stream = new FSFileInputStream(QString(url.c_str()));
-    if (stream->getStatus() != Ok) {
+    StreamBase<char>* stream = new FsFileInputStream(QString(url.c_str()));
+    if (stream->status() != Ok) {
         delete stream;
         stream = 0;
     }
@@ -68,7 +86,7 @@ public:
         return true;
     }
     bool open(QIODevice::OpenMode mode) {
-        if (mode & QIODevice::WriteOnly && !(mode & QIODevice::ReadOnly)) {
+        if ((mode & QIODevice::WriteOnly) && !(mode & QIODevice::ReadOnly)) {
             return false;
         }
         stream = reader->openStream(url);
@@ -95,7 +113,7 @@ public:
     QStringList entryList(QDir::Filters filters,
         const QStringList & filterNames) const {
         QStringList l;
-        DirLister dl = reader->getDirEntries(url);
+        DirLister dl = reader->dirEntries(url);
         EntryInfo e;
         while (dl.nextEntry(e)) {
             l << e.filename.c_str();
@@ -117,7 +135,7 @@ public:
     FileFlags fileFlags(FileFlags type) const;
     qint64 read(char* data, qint64 maxlen) {
         int nread = -1;
-        if (stream && stream->getStatus() == Ok) {
+        if (stream && stream->status() == Ok) {
             if (maxlen > 0) {
                 const char* c;
                 nread = stream->read(c, maxlen, maxlen);
