@@ -33,7 +33,6 @@
 using namespace std;
 
 DBusHandler::DBusHandler() {
-    int ret;
     DBusError err;
 
     pipe(quitpipe);
@@ -96,16 +95,15 @@ DBusHandler::handle() {
         printf("could not get connection fd\n");
     }
     dbus_threads_init_default();
-    //dbus_connection_set_exit_on_disconnect(conn, FALSE);
-    //printf("exit on disconnect: %i\n", conn->exit_on_disconnect);
 
     // loop, testing for new messages
     fd_set rfds;
     int retval;
     struct timeval tv;
     int max = ((fd>*quitpipe) ?fd :*quitpipe)+1;
-    // handle messages in queue
+    // handle messages that are initially in queue
     while (dbus_connection_dispatch(conn) == DBUS_DISPATCH_DATA_REMAINS) {}
+    dbus_connection_flush(conn);
     while (dbus_connection_get_is_connected(conn)) {
         FD_ZERO(&rfds);
         FD_SET(fd, &rfds);
@@ -114,7 +112,7 @@ DBusHandler::handle() {
         tv.tv_sec = 1000;
         tv.tv_usec = 0;
         retval = select(max, &rfds, NULL, NULL, &tv);
-        if (retval == -1 || FD_ISSET(*quitpipe, &rfds)) { // quit
+        if (retval == -1) {
             break;
         }
         // blocking read of the next available message
@@ -123,6 +121,9 @@ DBusHandler::handle() {
             ;
         }
         dbus_connection_flush(conn);
+        if (FD_ISSET(*quitpipe, &rfds)) { // quit
+            break;
+        }
     }
 
     for (vector<DBusObjectCallHandler*>::const_iterator i=callhandlers.begin();
