@@ -33,6 +33,7 @@
 class DBusMessageWriter {
     DBusConnection* const conn;
     DBusMessage* const reply;
+    DBusMessage* const reply_to;
     DBusMessage* error;
 public:
     DBusMessageIter it;
@@ -40,22 +41,25 @@ public:
     DBusMessageWriter(DBusConnection* conn, DBusMessage* msg);
     DBusMessageWriter(DBusConnection* conn, const char* objectpath,
         const char* interface, const char* function);
-    DBusMessageWriter() :conn(0), reply(0) { }
+    DBusMessageWriter() :conn(0), reply(0), reply_to(0), error(0) { }
     ~DBusMessageWriter();
     void setError(const std::string& error);
 };
 
 DBusMessageWriter& operator<<(DBusMessageWriter&, bool b);
 DBusMessageWriter& operator<<(DBusMessageWriter&, int32_t i);
+DBusMessageWriter& operator<<(DBusMessageWriter&, uint32_t i);
 DBusMessageWriter& operator<<(DBusMessageWriter&, int64_t i);
 DBusMessageWriter& operator<<(DBusMessageWriter&, double d);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::string& s);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::set<std::string>& s);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::vector<int32_t>& s);
+DBusMessageWriter& operator<<(DBusMessageWriter&, const std::vector<uint32_t>& s);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::vector<std::string>& s);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::map<std::string, std::string>& s);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::vector<std::pair<bool, std::string> >& s);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::multimap<int, std::string>&);
 DBusMessageWriter& operator<<(DBusMessageWriter&, const std::vector<std::pair<std::string, dbus_uint32_t> >&);
+DBusMessageWriter& operator<<(DBusMessageWriter&, const std::vector<std::vector<std::string> >&);
 
 #endif
