@@ -17,7 +17,6 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
 */
-#include <stdio.h>
 
 #include "eventlistenerqueue.h"
 #include "event.h"
@@ -26,6 +25,7 @@
 
 #include <algorithm>
 #include <iostream>
+#include <stdio.h>
 
 using namespace std;
 
@@ -292,6 +292,11 @@ void EventListenerQueue::updateEventType (Event* oldEvent, Event* newEvent,
     //     D     |     U     | IMPOSSIBLE
     //     D     |     C     |     U
     
+    /*STRIGI_LOG_DEBUG ("strigi.EventListener.Queue.updateEventType",
+                      "old event: " + oldEvent->toString())
+    STRIGI_LOG_DEBUG ("strigi.EventListener.Queue.updateEventType",
+                      "new event: " + newEvent->toString())*/
+    
     switch (oldEvent->getType())
     {
         case Event::CREATED:
@@ -300,8 +305,8 @@ void EventListenerQueue::updateEventType (Event* oldEvent, Event* newEvent,
             {
                 case Event::CREATED:
                     STRIGI_LOG_INFO("strigi.EventListenerQueue.updateEventType",
-                                    "Maybe we've lost some filesystem event");
-                    
+                                    "CREATED --> CREATED - "
+                                    "Maybe we have lost some filesystem event");
                     // put in update state, it's the safer solution because with
                     // update event we make a delete and a create
                     oldEvent->setType( Event::UPDATED);
@@ -328,7 +333,8 @@ void EventListenerQueue::updateEventType (Event* oldEvent, Event* newEvent,
             {
                 case Event::CREATED:
                     STRIGI_LOG_INFO("strigi.EventListenerQueue.updateEventType",
-                                    "Maybe we've lost some filesystem event");
+                                    "UPDATED --> CREATED - "
+                                    "Maybe we have lost some filesystem event");
                     // leave UPDATED state, it's the safer solution because with
                     // update event we make a delete and a create
                     break;
@@ -357,7 +363,8 @@ void EventListenerQueue::updateEventType (Event* oldEvent, Event* newEvent,
                     break;
                 case Event::UPDATED:
                     STRIGI_LOG_INFO("strigi.EventListenerQueue.updateEventType",
-                                     "Maybe we've lost some filesystem event");
+                                     "DELETED --> UPDATED - "
+                                     "Maybe we have lost some filesystem event");
                     
                     // put in update state, it's the safer solution because with
                     // update event we make a delete and a create
@@ -365,7 +372,8 @@ void EventListenerQueue::updateEventType (Event* oldEvent, Event* newEvent,
                     break;
                 case Event::DELETED:
                     STRIGI_LOG_INFO("strigi.EventListenerQueue.updateEventType",
-                                    "Maybe we've lost some filesystem event");
+                                    "DELETED -> DELETED - "
+                                    "Maybe we have lost some filesystem event");
                     //leave DELETED state
                     break;
             }
@@ -388,7 +396,7 @@ void EventListenerQueue::addEvents (vector<Event*> events)
         if (event)
         {
             // not to much time ago we have processed an event regarding
-            // the same file/dir, we've to wait a little before processing this
+            // the same file/dir, we have to wait a little before processing this
             // new event
             putInWaiting (*iter);
             continue;
