@@ -89,6 +89,8 @@ public:
     BooleanQuery* createBooleanQuery(const Strigi::Query& query);
     static void addField(lucene::document::Field* field, IndexedDocument&);
     Variant getFieldValue(lucene::document::Field* field, Variant::Type) const;
+
+    vector<IndexedDocument> strigiSpecial(const string& command);
 };
 const wchar_t*
 CLuceneIndexReader::Private::systemlocation() {
@@ -122,8 +124,10 @@ CLuceneIndexReader::Private::content() {
 }
 
 CLuceneIndexReader::CLuceneIndexReader(CLuceneIndexManager* m,
-    const string& dir) :manager(m), p(new Private(*this)), dbdir(dir), otime(0),
+    const string& dir) :manager(m), p(new Private(*this)), dbdir(dir),
         reader(0) {
+    otime.tv_sec = 0;
+    otime.tv_usec = 0;
     openReader();
 }
 
@@ -142,8 +146,8 @@ CLuceneIndexReader::openReader() {
         } else {
             reader = lucene::index::IndexReader::open(dbdir.c_str());
         }
-        //fprintf(stderr,
-        //"reader at %s: %i\n", dbdir.c_str(), reader->numDocs());
+        // fprintf(stderr,
+        // "READER at %s: %i\n", dbdir.c_str(), reader->numDocs());
     } catch (CLuceneError& err) {
         fprintf(stderr, "could not create reader %s: %s\n", dbdir.c_str(),
             err.what());
@@ -163,12 +167,18 @@ CLuceneIndexReader::closeReader() {
 }
 bool
 CLuceneIndexReader::checkReader(bool enforceCurrent) {
-    if (manager->indexMTime() > otime) {
-        struct timeval t;
-        gettimeofday(&t, 0);
-        if (enforceCurrent || t.tv_sec-otime > 60) {
-            otime = t.tv_sec;
+    struct timeval mtime = manager->indexMTime();
+    if (mtime.tv_sec != otime.tv_sec || mtime.tv_usec != otime.tv_usec) {
+        if (enforceCurrent) {
+            otime = mtime;
             closeReader();
+        } else {
+            struct timeval now;
+            gettimeofday(&now, 0);
+            if (now.tv_sec - otime.tv_sec > 60) {
+                otime = mtime;
+                closeReader();
+            }
         }
     }
     if (reader == 0) {
@@ -374,6 +384,11 @@ CLuceneIndexReader::Private::getFieldValue(lucene::document::Field* field,
 int32_t
 CLuceneIndexReader::countHits(const Strigi::Query& q) {
     if (!checkReader()) return -1;
+    // if the query is empty, we return the number of files in the index
+    if (q.term().string().size() == 0 && q.subQueries().size() == 0) {
+        return countDocuments();
+    }
+
     Query* bq = p->createQuery(q);
     if (reader == 0) {
         return 0;
@@ -421,6 +436,13 @@ CLuceneIndexReader::query(const Strigi::Query& q, int off, int max) {
     if (!checkReader()) {
         return results;
     }
+if (q.fields().size() > 0) cerr << q.fields()[0] << endl;
+    // handle special commands
+    if (q.fields().size() == 1 && q.fields()[0].empty()
+            && q.term().string().substr(0, 14) == "strigispecial:") {
+        return p->strigiSpecial(q.term().string());
+    }
+
     Query* bq = p->createQuery(q);
     IndexSearcher searcher(reader);
     Hits* hits = 0;
@@ -458,6 +480,45 @@ CLuceneIndexReader::query(const Strigi::Query& q, int off, int max) {
     return results;
 }
 void
+CLuceneIndexReader::getDocuments(const std::vector<std::string>& fullFields,
+        const std::vector<Strigi::Variant::Type>& types,
+        std::vector<std::vector<Strigi::Variant> >& result, int off, int max) {
+    int pos = 0;
+    int maxDoc = reader->maxDoc();
+    for (int i=0; i<off; i++) {
+        while (pos < maxDoc && reader->isDeleted(pos)) pos++;
+        if (pos == maxDoc) return;
+        pos++;
+    }
+    if (max < 0) max = 0;
+    result.resize(max);
+    Document* d = new Document();
+    for (int i = 0; i < max && pos < maxDoc; ++i) {
+        while (pos < maxDoc && reader->isDeleted(pos)) pos++;
+        d->clear();
+        if (pos == maxDoc || !reader->document(pos++, d)) {
+            continue;
+        }
+        
+        vector<Variant>& doc = result[i];
+        doc.clear();
+        doc.resize(fullFields.size());
+
+        DocumentFieldEnumeration* e = d->fields();
+        while (e->hasMoreElements()) {
+            Field* field = e->nextElement();
+            string name(wchartoutf8(field->name()));
+            for (uint j = 0; j < fullFields.size(); ++j) {
+                if (fullFields[j] == name) {
+                    doc[j] = p->getFieldValue(field, types[j]);
+                }
+            }
+        }
+        _CLDELETE(e);
+    }
+    delete d;
+}
+void
 CLuceneIndexReader::getHits(const Strigi::Query& q,
         const std::vector<std::string>& fields,
         const std::vector<Strigi::Variant::Type>& types,
@@ -467,6 +528,24 @@ CLuceneIndexReader::getHits(const Strigi::Query& q,
         return;
     }
 
+    vector<string> fullFields;
+    fullFields.resize(fields.size());
+    for (size_t i = 0; i < fields.size(); i++) {
+        if (fields[i].compare(0, 6, "xesam:") == 0) {
+            fullFields[i].assign(
+                "http://freedesktop.org/standards/xesam/1.0/core#"
+                + fields[i].substr(6));
+        } else {
+            fullFields[i].assign(fields[i]);
+        }
+    }
+
+    // if the query is empty, we return the number of files in the index
+    if (q.term().string().size() == 0 && q.subQueries().size() == 0) {
+        getDocuments(fullFields, types, result, off, max);
+        return;
+    }
+
     Query* bq = p->createQuery(q);
     IndexSearcher searcher(reader);
     Hits* hits = 0;
@@ -495,8 +574,8 @@ CLuceneIndexReader::getHits(const Strigi::Query& q,
         while (e->hasMoreElements()) {
             Field* field = e->nextElement();
             string name(wchartoutf8(field->name()));
-            for (uint j = 0; j < fields.size(); ++j) {
-                if (fields[j] == name) {
+            for (uint j = 0; j < fullFields.size(); ++j) {
+                if (fullFields[j] == name) {
                     doc[j] = p->getFieldValue(field, types[j]);
                 }
             }
@@ -511,9 +590,9 @@ CLuceneIndexReader::getHits(const Strigi::Query& q,
 }
 int32_t
 CLuceneIndexReader::countDocuments() {
-    if (!checkReader()) return -1;
+    if (!checkReader(true)) return -1;
     if (doccount == -1) {
-        doccount = manager->docCount();
+        doccount = reader->numDocs();
     }
     return doccount;
 }
@@ -685,6 +764,7 @@ CLuceneIndexReader::fieldNames() {
         return s;
     }
     TCHAR** names = reader->getFieldNames();
+    if (names == 0) return s;
     TCHAR** n = names;
     while (*n) {
         string str(wchartoutf8(*n));
@@ -741,8 +821,8 @@ CLuceneIndexReader::keywords(const string& keywordmatch,
 }
 void
 CLuceneIndexReader::getChildren(const std::string& parent,
-            std::map<std::string, time_t>& childs) {
-    childs.clear();
+            std::map<std::string, time_t>& children) {
+    children.clear();
     // force a fresh reader. This is important because the function
     // getChildren is essential for updating the index
     if ( !checkReader(true) ) {
@@ -772,7 +852,7 @@ CLuceneIndexReader::getChildren(const std::string& parent,
             time_t mtime = atoi(wchartoutf8( v ).c_str());
             v = d->get(Private::systemlocation());
             if (v) {
-                childs[wchartoutf8( v )] = mtime;
+                children[wchartoutf8( v )] = mtime;
             }
         }
 
@@ -783,3 +863,41 @@ CLuceneIndexReader::getChildren(const std::string& parent,
     searcher.close();
     _CLDELETE(q);
 }
+vector<IndexedDocument>
+CLuceneIndexReader::Private::strigiSpecial(const string& command) {
+    vector<IndexedDocument> r;
+cerr << "strigispecial " << command << endl;
+    // we are going to count the size of each of the fields in this index
+    // this requires that we loop through all fields
+    lucene::index::TermEnum* terms = reader.reader->terms();
+
+    map<const TCHAR *, int64_t> lengths;
+    while (terms->next()) {
+        lengths[terms->term()->field()] += terms->term()->textLength();
+       // cerr << wchartoutf8(terms->term()->field()) << '\t'
+        //    << wchartoutf8(terms->term()->text()) << endl;
+    }
+    int64_t total = 0;
+    for (map<const TCHAR *, int64_t>::const_iterator i = lengths.begin();
+            i != lengths.end(); ++i) {
+        cerr << wchartoutf8(i->first) << '\t' << i->second << endl;
+        total += i->second;
+    }
+    terms->close();
+    cerr << "total" << '\t' << total << endl;
+
+    int32_t max = reader.reader->numDocs();
+    for (int32_t i=0; i < max; ++i) {
+        lucene::document::Document* d = reader.reader->document(i);
+        lucene::document::DocumentFieldEnumeration* e = d->fields();
+        while (e->hasMoreElements()) {
+            Field* f = e->nextElement();
+            if (f->isStored()) {
+                total += wcslen(f->stringValue());
+            }
+        }
+        delete d;
+    }
+    cerr << "total" << '\t' << total << endl;
+    return r;
+}
