@@ -17,8 +17,8 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#ifndef STRIGI_INDEXERCONFIGURATION_H
-#define STRIGI_INDEXERCONFIGURATION_H
+#ifndef STRIGI_ANALYZERCONFIGURATION_H
+#define STRIGI_ANALYZERCONFIGURATION_H
 
 #include "streamendanalyzer.h"
 #include "streamsaxanalyzer.h"
@@ -67,7 +67,7 @@ enum FieldType {
                              should be tokenized. */
 };
 private:
-    AnalyzerConfigurationPrivate* p;
+    AnalyzerConfigurationPrivate* const p;
 public:
     AnalyzerConfiguration();
     virtual ~AnalyzerConfiguration();
@@ -173,7 +173,7 @@ public:
      * index the archive's children.
      *
      * This can be used to stop the indexing process at the next convenient
-     * time.  For example, if the user wishes to interupt the indexing
+     * time.  For example, if the user wishes to interrupt the indexing
      * process, or if the tool @c deepgrep was asked to find the first
      * occurrence of a term and then stop.
      *
@@ -212,7 +212,7 @@ public:
      * @return the maximal number of bytes that may be read, or -1 if there is
      *         no limit
      **/
-    virtual int64_t maximalStreamReadLength(const Strigi::AnalysisResult& ar) {
+    virtual int64_t maximalStreamReadLength(const Strigi::AnalysisResult&/*ar*/) {
         return -1;
     }
     /**
