@@ -61,21 +61,25 @@ HelperProgramConfig::HelperProgramConfig() {
     };*/
 
     // make a vector with all the paths
-    const char* path =getenv("PATH");
     vector<string> paths;
-    const char* end = strchr(path, ':');
-    while (end) {
-        if (path[0] == '/') {
-            paths.push_back(string(path, end-path));
-        }
-        path = end+1;
-        end = strchr(path, ':');
+    string path;
+    if (getenv("PATH")) {
+        path.assign(getenv("PATH"));
     }
-    if (path[0] == '/') {
-        paths.push_back(path);
+    string::size_type start = 0;
+    string::size_type end = path.find(':');
+    while (end != string::npos) {
+        if (path[start] == '/') {
+            paths.push_back(path.substr(start, end-start));
+        }
+        start = end + 1;
+        end = path.find(':', start);
+    }
+    if (start < path.size() && path[start] == '/') {
+        paths.push_back(path.substr(start));
     }
 
-/*    string exepath = findPath("pdftotext", paths);
+    string exepath = findPath("pdftotext", paths);
     if (exepath.length()) {
         HelperRecord* h = new HelperRecord();
         h->magic = (unsigned char*)"%PDF-1.";
@@ -87,7 +91,7 @@ HelperProgramConfig::HelperProgramConfig() {
         h->arguments.push_back("-");
         h->readfromstdin = false;
         helpers.push_back(h);
-    }*/
+    }
     // this  does not work atm because it requires help programs itself
 /*    exepath = findPath("wvWare", paths);
     if (exepath.length()) {
