@@ -78,7 +78,7 @@ WordText::addText(const char* d, size_t l, iconv_t conv) {
     size_t inbytesleft = l;
     char* outbuf = out + len;
     size_t outbytesleft = capacity - len;
-    size_t r = iconv(conv, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
+    /*size_t r =*/ iconv(conv, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
      
     //fprintf(stderr, "%x %i %i added %i bytes %p\n", *d, r, inbytesleft,
     //    capacity-outbytesleft-len, conv);
@@ -134,35 +134,41 @@ OleEndAnalyzerFactory::registerFields(FieldRegister& reg) {
         0xAB,0x91,0x08,0x00,0x2B,0x27,0xB3,0xD9};
     static const char docSummaryKey[]= {0x02,0xD5,0xCD,0xD5,0x9C,0x2E,0x1B,0x10,
         0x93,0x97,0x08,0x00,0x2B,0x2C,0xF9,0xAE};
-    const RegisteredField* r;
     string key;
-    map<int,const RegisteredField*>* m;
+    key.assign(summaryKey, 16);
+    map<int,const RegisteredField*>* m = &fieldsMaps[key];
 
     // register the fields for the Summary Information Stream
-    key.assign(summaryKey, 16);
-    m = &fieldsMaps[key];
-    r = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#title");
-    if (r) (*m)[2] = r;
-    r = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#subject");
-    if (r) (*m)[3] = r;
-    r = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#author");
-    if (r) (*m)[4] = r;
-    r = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#contentKeyword");
-    if (r) (*m)[5] = r;
-    r = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#contentComment");
-    if (r) (*m)[6] = r;
+    (*m)[2] = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#title");
+    addField((*m)[2]);
+    (*m)[3] = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#subject");
+    addField((*m)[3]);
+    (*m)[4] = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#author");
+    addField((*m)[4]);
+    (*m)[5] = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#contentKeyword");
+    addField((*m)[5]);
+    (*m)[6] = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#contentComment");
+    addField((*m)[6]);
 
     // register the fields for the Document Summary Information Stream
     key.assign(docSummaryKey, 16);
     m = &fieldsMaps[key];
-    r = reg.registerField("ole.category", FieldRegister::stringType, 1, 0);
-    if (r) (*m)[2] = r;
-    r = reg.registerField("ole.presentationtarget",FieldRegister::stringType, 1, 0);
-    if (r) (*m)[3] = r;
-    r = reg.registerField("ole.manager", FieldRegister::stringType, 1, 0);
-    if (r) (*m)[14] = r;
-    r = reg.registerField("ole.company", FieldRegister::stringType, 1, 0);
-    if (r) (*m)[15] = r;
+    (*m)[2] = reg.registerField("ole.category");
+    addField((*m)[2]);
+    (*m)[3] = reg.registerField("ole.presentationtarget");
+    addField((*m)[3]);
+    (*m)[14] = reg.registerField("ole.manager");
+    addField((*m)[14]);
+    (*m)[15] = reg.registerField("ole.company");
+    addField((*m)[15]);
+
+    typeField = reg.typeField;
+    addField(typeField);
 }
 const map<int, const RegisteredField*>*
 OleEndAnalyzerFactory::getFieldMap(const string& key) const {
@@ -170,7 +176,8 @@ OleEndAnalyzerFactory::getFieldMap(const string& key) const {
         = fieldsMaps.find(key);
     return (i == fieldsMaps.end()) ?0 :&i->second;
 }
-// parse with info from http://www.wotsit.org/getfile.asp?file=wword8&sc=230027800
+// parse with info from
+// http://www.wotsit.org/getfile.asp?file=wword8&sc=230027800
 bool
 OleEndAnalyzer::tryFIB(AnalysisResult& ar, InputStream* in) {
     const char* d;
@@ -296,13 +303,14 @@ OleEndAnalyzer::handleProperty(AnalysisResult* result,
         return;
     }
     int32_t datatype = readLittleEndianInt32(data);
-    // currently we only support null-terminated strings
     if (datatype == 30) {
         int32_t len = readLittleEndianInt32(data+4);
-        if (len > 0 && len-8 <= end-data) {
-            // TODO perhaps we should use the encoding fixer here too
-            // but, check the unit tests if you do
-            result->addValue(field, data+8, len-1);
+        data += 8;
+        if (len > 0 && len <= end-data) {
+            // remove trailing '\0' characters
+            while (len > 0 && data[len-1] == 0) len--;
+            // report the field
+            result->addValue(field, data, len);
         }
     }
 }
@@ -392,6 +400,7 @@ OleEndAnalyzer::analyze(AnalysisResult& ar, InputStream* in) {
         m_error = ole.error();
         return -1;
     } else {
+        ar.addValue(factory->typeField, "http://freedesktop.org/standards/xesam/1.0/core#Document");
         m_error.resize(0);
     }
     return 0;
