@@ -32,6 +32,7 @@ const string ID3V2ThroughAnalyzerFactory::albumFieldName("http://freedesktop.org
 const string ID3V2ThroughAnalyzerFactory::composerFieldName("http://freedesktop.org/standards/xesam/1.0/core#composer");
 const string ID3V2ThroughAnalyzerFactory::genreFieldName("http://freedesktop.org/standards/xesam/1.0/core#genre");
 const string ID3V2ThroughAnalyzerFactory::trackNumberFieldName("http://freedesktop.org/standards/xesam/1.0/core#trackNumber");
+const string ID3V2ThroughAnalyzerFactory::albumTrackCountFieldName("http://freedesktop.org/standards/xesam/1.0/core#albumTrackCount");
 const string ID3V2ThroughAnalyzerFactory::discNumberFieldName("http://freedesktop.org/standards/xesam/1.0/core#discNumber");
 
 void
@@ -42,7 +43,10 @@ ID3V2ThroughAnalyzerFactory::registerFields(FieldRegister& r) {
     genreField = r.registerField(genreFieldName);
     composerField = r.registerField(composerFieldName);
     trackNumberField = r.registerField(trackNumberFieldName);  //FIXME:id3 track numbers can look like this: 1/10
+    albumTrackCountField = r.registerField(albumTrackCountFieldName);
     discNumberField = r.registerField(discNumberFieldName);  //FIXME:id3 disc numbers can looklike this: 1/2
+
+    typeField = r.typeField;
 }
 
 void
@@ -87,12 +91,13 @@ ID3V2ThroughAnalyzer::connectInputStream(InputStream* in) {
     // read the entire tag
     nread = in->read(buf, size, size);
     in->reset(0);
-    if (nread != size) {
+    if (nread != size || !indexable) {
         return in;
     }
+    indexable->addValue(factory->typeField, "http://freedesktop.org/standards/xesam/1.0/core#Music");
     const char* p = buf + 10;
     buf += size;
-    while (indexable && p < buf && *p) {
+    while (p < buf && *p) {
         size = readSize((unsigned char*)p+4, async);
         if (size < 0 || size > (buf-p)-11) {
             // cerr << "size < 0: " << size << endl;
