@@ -16,7 +16,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- *  $Id: m3ustreamanalyzer.cpp 717846 2007-09-27 17:16:00Z evgeny $
+ *  $Id: m3ustreamanalyzer.cpp 780344 2008-02-28 20:51:00Z vandenoever $
  */
 
 #include "m3ustreamanalyzer.h"
@@ -31,8 +31,15 @@ void M3uLineAnalyzerFactory::registerFields(Strigi::FieldRegister& reg)
 {
 // track list length is easily obtained via API
 //    tracksField = reg.registerField();
-    trackPathField = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#links");
-    m3uTypeField = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#formatSubtype");
+    trackPathField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#links");
+    m3uTypeField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#formatSubtype");
+    typeField = reg.typeField;
+
+    addField(trackPathField);
+    addField(m3uTypeField);
+    addField(typeField);
 }
 
 // Analyzer
@@ -80,5 +87,8 @@ void M3uLineAnalyzer::endAnalysis(bool complete)
     // tracksField has not been initialized, so don't use it
     //if (complete && extensionOk)
         //analysisResult->addValue(factory->tracksField, count);
+    if (complete && extensionOk)
+        analysisResult->addValue(factory->typeField, "http://freedesktop.org/standards/xesam/1.0/core#AudioList");
+
 }
 
