@@ -30,7 +30,7 @@
 #include "textendanalyzer.h"
 #include "tarendanalyzer.h"
 #include "arendanalyzer.h"
-#include "zipendanalyzer.h"
+#include "zipexeendanalyzer.h"
 #include "oleendanalyzer.h"
 #include "rpmendanalyzer.h"
 #include "cpioendanalyzer.h"
@@ -55,6 +55,7 @@
 #include "analyzerloader.h"
 #include "eventthroughanalyzer.h"
 #include "htmlsaxanalyzer.h"
+#include "indexpluginloader.h"
 #include <sys/stat.h>
 #ifdef WIN32
  #include "ifilterendanalyzer.h"
@@ -81,6 +82,7 @@ public:
 
     AnalyzerLoader* moduleLoader;
     const RegisteredField* sizefield;
+    const RegisteredField* errorfield;
     void initializeThroughFactories();
     void initializeEndFactories();
     void initializeSaxFactories();
@@ -101,16 +103,19 @@ public:
 };
 
 } // namespace Strigi
-
 StreamAnalyzerPrivate::StreamAnalyzerPrivate(AnalyzerConfiguration& c)
         :conf(c), writer(0) {
     moduleLoader = new AnalyzerLoader();
     sizefield = c.fieldRegister().sizeField;
+    errorfield = c.fieldRegister().parseErrorField;
 
     // load the plugins from the environment setting
     const char* strigipluginpath(getenv("STRIGI_PLUGIN_PATH"));
     if (strigipluginpath) {
-        moduleLoader->loadPlugins(strigipluginpath);
+        vector<string> strigipluginpaths = getdirs(strigipluginpath);
+        for (uint i=0; i<strigipluginpaths.size(); ++i) {
+            moduleLoader->loadPlugins(strigipluginpaths[i].c_str());
+        }
     } else {
         moduleLoader->loadPlugins( LIBINSTALLDIR "/strigi");
     }
@@ -312,6 +317,7 @@ StreamAnalyzerPrivate::initializeEndFactories() {
     addFactory(new MailEndAnalyzerFactory());
     addFactory(new MpegEndAnalyzerFactory());
     addFactory(new ZipEndAnalyzerFactory());
+    addFactory(new ZipExeEndAnalyzerFactory());
     addFactory(new RpmEndAnalyzerFactory());
     addFactory(new CpioEndAnalyzerFactory());
     addFactory(new PngEndAnalyzerFactory());
@@ -354,7 +360,7 @@ StreamAnalyzer::analyze(AnalysisResult& idx, StreamBase<char>* input) {
 }
 char
 StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
-//    cerr << "StreamAnalyzerPrivate::analyze " << idx.path().c_str() << endl;
+    //cerr << "analyze " << idx.path().c_str() << endl;
 
     // retrieve or construct the through analyzers and end analyzers
     vector<vector<StreamThroughAnalyzer*> >::iterator tIter;
@@ -400,13 +406,20 @@ StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
         headersize = -1;
         finished = true;
     }
-    int es = 0, size = eIter->size();
-    while (!finished && es != size) {
+    int es = 0;
+    int itersize = eIter->size();
+    while (!finished && es != itersize) {
         StreamEndAnalyzer* sea = (*eIter)[es];
         if (sea->checkHeader(header, headersize)) {
             idx.setEndAnalyzer(sea);
             char ar = sea->analyze(idx, input);
             if (ar) {
+                idx.addValue(errorfield, sea->name() + string(": ")
+                    + sea->error());
+                if (!idx.config().indexMore()) {
+                    removeIndexable(idx.depth());
+                    return -1;
+                }
                 int64_t pos = input->reset(0);
                 if (pos != 0) { // could not reset
                     cerr << "could not reset stream of " << idx.path().c_str()
@@ -418,8 +431,9 @@ StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
                     // refresh the pointer to the start of the data
                     headersize = input->read(header, headersize, headersize);
     		    if (input->reset(0) != 0) {
-        		cerr << "resetting again is impossible!! pos: " << input->position()
-            		     << " status: " << input->status() << endl;
+        		cerr << "resetting again is impossible!! pos: "
+                             << input->position() << " status: "
+                             << input->status() << endl;
     		    }
                     if (headersize < 0) finished = true;
                 }
@@ -428,6 +442,9 @@ StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
             }
             eIter = end.begin() + idx.depth();
         }
+        if (!finished) {
+            finished = !conf.indexMore();
+        }
         es++;
     }
     idx.setEndAnalyzer(0);
@@ -437,12 +454,16 @@ StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
         tIter = through.begin() + idx.depth();
         uint32_t skipsize = 4096;
         do {
+            // ask the analyzerconfiguration if we should continue
+            int64_t max = idx.config().maximalStreamReadLength(idx);
+            if (!idx.config().indexMore()
+                    || (max != -1 && input->position() >= max)) {
+                // we are done
+                return 0;
+            }
             ready = input->size() != -1;
             vector<StreamThroughAnalyzer*>::iterator ts;
             for (ts = tIter->begin(); ready && ts != tIter->end(); ++ts) {
-                //if (!(*ts)->isReadyWithStream()) {
-                //    cerr << "not ready " << (*ts)->name() << endl;
-                //}
                 ready = (*ts)->isReadyWithStream();
             }
             if (!ready) {
