@@ -59,6 +59,9 @@ private:
     const Strigi::RegisteredField* colorDepthField;
     const Strigi::RegisteredField* widthField;
     const Strigi::RegisteredField* heightField;
+
+    const Strigi::RegisteredField* typeField;
+
     const char* name() const {
         return "GifThroughAnalyzer";
     }
@@ -72,9 +75,18 @@ private:
 
 void
 GifThroughAnalyzerFactory::registerFields(FieldRegister& reg) {
-    colorDepthField = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#pixelDataBitDepth");
-    widthField = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#width");
-    heightField = reg.registerField("http://freedesktop.org/standards/xesam/1.0/core#height");
+    colorDepthField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#pixelDataBitDepth");
+    widthField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#width");
+    heightField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#height");
+    typeField = reg.typeField;
+
+    addField(colorDepthField);
+    addField(widthField);
+    addField(heightField);
+    addField(typeField);
 }
 
 // Analyzer
@@ -105,6 +117,8 @@ GifThroughAnalyzer::connectInputStream(InputStream* in) {
         analysisResult->addValue(factory->colorDepthField, (uint32_t)colorDepth);
     }
 
+    analysisResult->addValue(factory->typeField, "http://freedesktop.org/standards/xesam/1.0/core#Image");
+
     return in;
 }
 
