@@ -18,7 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 #ifndef STRIGI_ARCHIVEREADER_H
-#define STRIGI_ARCHIVEREADER_H
+#define STRIGI_ARCHIVEREADER_H 
 
 #include <map>
 #include <list>
@@ -107,7 +107,7 @@ public:
 class STREAMS_EXPORT ArchiveReader : public StreamOpener {
 private:
     class ArchiveReaderPrivate;
-    ArchiveReaderPrivate *p;
+    ArchiveReaderPrivate* const p;
 
 public:
     /** Constructor */
