@@ -55,7 +55,7 @@ TarInputStream::readHeader() {
     return begin;
 }
 bool
-TarInputStream::checkHeader(const char* h, const int32_t hsize) {
+TarInputStream::checkHeader(const char* h, int32_t hsize) {
     if (hsize < 257) {
         // header is too small to check
         return false;
@@ -88,7 +88,7 @@ TarInputStream::parseHeader() {
         return;
     }
 
-    int32_t len = strlen(hb);
+    int32_t len = std::strlen(hb);
     if (len == 0) {
         // ready
         m_status = Eof;
