@@ -20,10 +20,11 @@
 #include "../base64inputstream.h"
 #include "../fileinputstream.h"
 #include "inputstreamtests.h"
-using namespace jstreams;
+
+using namespace Strigi;
 
 int
-Base64InputStreamTest(int, char**) {
+Base64InputStreamTest(int, char*[]) {
     founderrors = 0;
     FileInputStream file("base64enc.txt");
     Base64InputStream b64(&file);
