@@ -21,10 +21,11 @@
 #include "../fileinputstream.h"
 #include "../rpminputstream.h"
 #include "inputstreamtests.h"
-using namespace jstreams;
+
+using namespace Strigi;
 
 int
-RpmInputStreamTest(int argc, char** argv) {
+RpmInputStreamTest(int argc, char* argv[]) {
     if (argc < 2) return 1;
     founderrors = 0;
     VERIFY(chdir(argv[1]) == 0);
