@@ -20,10 +20,11 @@
 #include "../fileinputstream.h"
 #include "../subinputstream.h"
 #include "inputstreamtests.h"
-using namespace jstreams;
+
+using namespace Strigi;
 
 int
-SubInputStreamTest(int argc, char** argv) {
+SubInputStreamTest(int argc, char* argv[]) {
     if (argc < 2) return 0;
     founderrors = 0;
     VERIFY(chdir(argv[1]) == 0);
