@@ -29,6 +29,7 @@
 #include "query.h"
 #include "queryparser.h"
 #include "xesam2strigi.h"
+#include "../daemon/strigilogging.h"
 #include <algorithm>
 #include <string>
 #include <set>
@@ -45,39 +46,6 @@ using namespace Strigi;
 map<char, string> options;
 vector<string> arguments;
 
-AnalyzerConfiguration::FieldType
-operator|(AnalyzerConfiguration::FieldType a, AnalyzerConfiguration::FieldType b){
-    return static_cast<AnalyzerConfiguration::FieldType>((int)a|(int)b);
-}
-
-class CustomAnalyzerConfiguration: public AnalyzerConfiguration {
-public:
-
-//    None       = 0x0000 /**< No hint. */,
-//    Binary     = 0x0001 /**< The field should be stored as binary data. */,
-//    Compressed = 0x0002 /**< If the field is stored, the data
-//                             should be compressed. */,
-//    Indexed    = 0x0004 /**< The field should be indexed. */,
-//    Stored     = 0x0020 /**< The field should be stored. */,
-//    Tokenized  = 0x0040 /**< If the field contains text, it
-//                             should be tokenized. */
-    AnalyzerConfiguration::FieldType indexType(const RegisteredField* field) const {
-	if (string("chemistry.inchi").compare(field->key()) == 0) {
-	    return Stored|Indexed;
-	} else if (string("chemistry.molecular_formula").compare(field->key()) == 0) {
-	    return Stored|Indexed;
-/*	} else if (string("chemistry.").compare(field->key()) == 0) {
-	    return Binary|Stored|Indexed;
-	} else if (string("chemistry.").compare(field->key()) == 0) {
-	    return Binary|Stored|Indexed;
-	} else if (string("chemistry.").compare(field->key()) == 0) {
-	    return Binary|Stored|Indexed; */
-	} else {
-	    return Tokenized|Stored|Indexed;
-	}
-    }
-};
-
 void
 parseArguments(int argc, char** argv) {
     // parse arguments
@@ -127,7 +95,7 @@ usage(int argc, char** argv) {
     pe("  %s create [-j num] -t backend -d indexdir [-i include] [-x exclude] files/dirs\n", cmd);
     pe("  %s deindex -t backend -d indexdir files/dirs\n", cmd);
     pe("  %s get -t backend -d indexdir files\n", cmd);
-    pe("  %s listFiles -t backend -d indexdir\n", cmd);
+    pe("  %s listFiles -t backend -d indexdir [parent dir]\n", cmd);
     pe("  %s listFields -t backend -d indexdir\n", cmd);
     //TODO: find a better definition for query?
     pe("  %s query -t backend -d indexdir queries\n", cmd);
@@ -278,7 +246,6 @@ create(int argc, char** argv) {
     filters.push_back(make_pair<bool,string>(true, included_filter));
     filters.push_back(make_pair<bool,string>(false, excluded_filter));
     
-    //CustomAnalyzerConfiguration config;
     AnalyzerConfiguration config;
     config.setFilters(filters);
 
@@ -368,8 +335,17 @@ listFiles(int argc, char** argv) {
     if (manager == 0) {
         return usage(argc, argv);
     }
+
     IndexReader* reader = manager->indexReader();
-    listFiles(reader, "");
+    if (arguments.empty())
+        listFiles(reader, "");
+
+    for (vector<string>::iterator iter = arguments.begin();
+         iter != arguments.end(); iter++) {
+        cout << "indexed files under " << *iter << endl;
+        listFiles(reader, *iter);
+    }
+    
     IndexPluginLoader::deleteIndexManager(manager);
     return 0;
 }
@@ -409,7 +385,7 @@ get(int argc, char** argv) {
             printf ("%s: is not indexed\n", iter->c_str());
         else
         {
-            printf ("Informations associated to %s:\n", iter->c_str());
+            printf ("Information associated to %s:\n", iter->c_str());
             for (vector<IndexedDocument>::iterator it = matches.begin();
                  it != matches.end(); it++)
             {
@@ -510,7 +486,7 @@ xesamquery(int argc, char** argv) {
     }
     
     if (arguments.size() != 0) {
-        pe("You don't have to provide other arguments.\n");
+        pe("You do not have to provide other arguments.\n");
         return usage(argc, argv);
         return 1;
     }
@@ -529,9 +505,9 @@ xesamquery(int argc, char** argv) {
         }
     }
     else if (ulfile.length() != 0) {
-      printf ("processing xesam userlanguage query from file %s\n", qlfile.c_str());
+      printf ("processing xesam userlanguage query from file %s\n", ulfile.c_str());
 
-      if (xesam2strigi.parse_file ( qlfile, Xesam2Strigi::UserLanguage))
+      if (xesam2strigi.parse_file ( ulfile, Xesam2Strigi::UserLanguage))
         printf ("Xesam query parsed successfully\n");
       else
       {
@@ -687,6 +663,9 @@ main(int argc, char** argv) {
     if (argc < 2) { 
         return usage(argc, argv);
     }
+
+    STRIGI_LOG_INIT_BASIC()
+    
     const char* cmd = argv[1];
     if (!strcmp(cmd,"create")) {
         return create(argc, argv);
